@@ -1,6 +1,6 @@
 __author__  = "Great Tomorrow(gr82morozr@gmail.com)"
 __license__ = "MIT"
-__version__ = "0.1.33",
+__version__ = "0.1.34",
 
 from .fs_tools        import  *
 from .img_tools       import  *
@@ -16,6 +16,6 @@ from .mail_tools      import  *
 from .dict_tools      import  *
 from .media_tools     import  *
 from .daemon_tools    import  *
-from .mouse_tools     import  *
+#from .mouse_tools     import  *
 from .helper          import  *
 
