@@ -34,26 +34,10 @@ def rm_folder(folder_name, empty=False):
   else:
     rmtree(folder_name,ignore_errors=True)
     mk_folder(folder_name=folder_name)
-    
-  """    
-    if is_folder(folder_name) == False :
-      return
-    
-    file_list = get_files(folder = folder_name, type='file')
-    dir_list  = get_files(folder = folder_name, type='dir')
-    for d in dir_list :
-      if file_exists(d) :
-        d_empty = True
-        for f in file_list :      
-          if f.find(d) == 0 :
-            d_empty = False
-            break
-        if d_empty == True:
-          rmtree(d,ignore_errors=True)
 
-  """
-  
 delete_folder = rm_folder
+rm_dir        = rm_folder
+
 
 ####################################################################################################
 
@@ -71,6 +55,9 @@ def mk_folder(folder_name) :
   if file_exists(folder_name) == False :
     os.makedirs(folder_name, exist_ok=True)
 
+create_folder = mk_folder
+make_folder   = mk_folder
+make_dir      = mk_folder
 ####################################################################################################
 
 
@@ -149,12 +136,10 @@ def parse_full_path (file_path):
 
 def file_exists(file_name):
   return os.path.exists(file_name)
+exists = file_exists
 
 
-
-def exists(file_name):
-  return file_exists(file_name)
-
+####################################################################################################
   
 def copy_file(src_file,dest_file):
   if file_exists(src_file) :  
@@ -194,7 +179,9 @@ def rm_file(file_name = None, folder = None, regex_pattern=None) :
   else:
     if os.path.isfile(file_name): 
       os.remove(file_name)
-        
+
+del_file = rm_file
+
 ####################################################################################################          
         
 def write_file(file_name, text, mode='w', is_new = False):
@@ -244,7 +231,6 @@ def get_md5_txt(text) :
 
 ####################################################################################################
 
-
   
 def is_file (file) :
   return os.path.isfile(file) 
@@ -261,7 +247,7 @@ def check_type(full_path):
   else:
     return None
   
-  
+####################################################################################################  
   
   
 def scan_fs_tree(folder, ext='', recursive=True, type='A'):
@@ -280,6 +266,9 @@ def scan_fs_tree(folder, ext='', recursive=True, type='A'):
           if obj.name.endswith(ext) :  yield obj
       pass
 
+####################################################################################################
+
+
 def gen_files(folder, ext='',  recursive=True, type='A'):
   for f in scan_fs_tree(folder=folder,  ext=ext, recursive=recursive, type=type):
     file_path = f.path
@@ -287,20 +276,25 @@ def gen_files(folder, ext='',  recursive=True, type='A'):
       file_path = file_path.replace('\\', '/')
     yield file_path
     
-
+####################################################################################################
 def get_files(folder, ext='', recursive=True, type='A') : 
   files = []
   for f in gen_files(folder=folder, ext = ext, recursive=recursive, type=type):
     files.append(f)
   return files
 
+####################################################################################################
+
 def get_file_info(file_name) :
   if file_exists(file_name):
     st = os.stat(file_name)
     return { "file_name": file_name, "size" : int(st[ST_SIZE]), "access_time" : st[ST_ATIME] }
   else:
     return None
-  
+
+####################################################################################################
+# 
+#   
 def get_folder_info(folder, recursive=True ):
   """
     
@@ -317,6 +311,7 @@ def get_folder_info(folder, recursive=True ):
   
   return (total_count, total_size)  
 
+####################################################################################################
 
 def do_zip(input_file=None,output_file=None,input_data=None, output="file"):
   """
@@ -357,6 +352,9 @@ def do_zip(input_file=None,output_file=None,input_data=None, output="file"):
 
   pass
 
+
+####################################################################################################
+
 def do_unzip(input_file=None,output_file=None,input_data=None, output="file"):
   """
   usage  : 
@@ -544,6 +542,7 @@ def base64_decode(input_file=None,output_file=None,input_data=None, output="file
     base64_decode(input_data="test_string",output="byte")
 
   """
+  
   assert output == "file" or  output == "byte" , "Wring output type : should be file or byte"
   input_text = None
 
